@@ -9,7 +9,7 @@
  * @license   http://opensource.org/licenses/bsd-license.php The BSD License
  */
 
-define('MOONY_VERSION', '0.11.1');
+define('MOONY_VERSION', '0.11.2');
 define('MOONY_ROOT_DIR', dirname(__FILE__));
 
 define('MOONY_TEMPLATE_DIR_KEY', 'moony_template_dir');
@@ -68,6 +68,18 @@ class Moony
      */
     var $internal_encoding;
 
+    /**
+     * アクションクラスが見つからない場合に実行されるアクション名
+     * @var string
+     */
+    var $default_action_name;
+
+    /**
+     * アクションクラスが見つからない場合のリダイレクト先
+     * @var string
+     */
+    var $default_redirect_url;
+
     /**
      * テンプレートエンジンとしてSmartyを使うかどうか
      * @var boolean
@@ -153,6 +165,30 @@ class Moony
         $this->internal_encoding = $internal_encoding;
     }
 
+    /**
+     * ルーティングの結果、アクションクラスが見つからなかった場合に
+     * デフォルトで実行されるアクションを設定します。
+     *
+     * @access public
+     * @param string $action_name アクション名
+     */
+    function setDefaultAction($action_name)
+    {
+        $this->default_action_name = $action_name;
+    }
+
+    /**
+     * ルーティングの結果、アクションクラスが
+     * 見つからなかった場合のリダイレクト先を設定します。
+     *
+     * @access public
+     * @param string $action_name アクション名
+     */
+    function setDefaultRedirect($redirect_url)
+    {
+        $this->default_redirect_url = $redirect_url;
+    }
+
     /**
      * テンプレートエンジンとしてSmartyを使用することにします。
      * $propertiesの個々の要素ははSmartyのプロパティとして設定されます。
