@@ -171,7 +171,7 @@ class Moony_Generator
             $this->_template_dir . DIRECTORY_SEPARATOR . $template_file;
         $template_skeleton = $this->_getTemplateSkeleton();
         $template_skeleton = sprintf(
-            $template_skeleton, $action_name, $action_name);
+            $template_skeleton, $action_name, $action_path, $template_path);
         $this->_createFile($template_path, $template_skeleton);
     }
 
@@ -239,7 +239,9 @@ class Moony_Generator
                   .  "\$moony->setTemplateDir('templates');\n"
                   .  "// \$moony->setInputEncoding('SJIS-win');\n"
                   .  "// \$moony->setOutputEncoding('SJIS-win');\n"
-                  .  "// \$moony->setInternalEncoding('UTF-8');\n";
+                  .  "// \$moony->setInternalEncoding('UTF-8');\n"
+                  .  "// \$moony->setDefaultAction('Index');\n"
+                  .  "// \$moony->setDefaultRedirect('http://example.com/');\n";
         if ($use_smarty) {
             $skeleton .= "\$moony->useSmarty(array(\n"
                       .  "    'compile_dir' => 'templates_c',\n"
@@ -282,11 +284,16 @@ class Moony_Generator
     {
         $skeleton = "<html>\n"
                   . "<head>\n"
-                  . "<title>action: %s</title>\n"
+                  . "    <title>It worked!</title>\n"
                   . "</head>\n"
                   . "<body>\n"
-                  . "<h1>action: %s</h1>\n"
-                  . "<p>Hello Moony!</p>\n"
+                  . "<h1>It worked!</h1>\n"
+                  . "<p>Congratulations on your action page of Moony, '%s'.</p>\n"
+                  . "<h2>working files</h2>\n"
+                  . "<ul>\n"
+                  . "    <li>action class: %s</li>\n"
+                  . "    <li>template file: %s</li>\n"
+                  . "</ul>\n"
                   . "</body>\n"
                   . "</html>\n";
         return $skeleton;
