@@ -26,13 +26,23 @@ class Moony_Router
      * PATH_INFOを元に実行する
      * アクションクラスを探索、処理を起動します。
      *
+     * アクションクラスが見つからず、
+     * デフォルトアクションがMoony::setDefaultAction()で
+     * 設定されている場合はそのアクションを起動します。
+     *
+     * デフォルトのリダイレクト先がMoony::setDefaultRedirect()で
+     * 設定されている場合はそのURLにリダイレクトします。
+     *
+     * 結局見つからなかった場合、HTTPのステータスで404を送出します。
+     *
      * @access public
      * @param object $moony Moony
      */
     function route(&$moony)
     {
-        $action_dir = $moony->action_dir;
-        if (is_null($action_dir)) {
+        $default_action_name = $moony->default_action_name;
+
+        if (is_null($moony->action_dir)) {
             // アクションクラスを格納するディレクトリが設定されていない
             trigger_error('Not defined: action_dir', E_USER_ERROR);
             header('HTTP/1.0 500 Internal Server Error');
@@ -51,25 +61,40 @@ class Moony_Router
         while (count($paths) > 0) {
 
             $action_path = implode(DIRECTORY_SEPARATOR, $paths);
-            $path = $action_dir . DIRECTORY_SEPARATOR . $action_path . '.php';
+            $action_name = str_replace(DIRECTORY_SEPARATOR, '_', $action_path);
 
-            if (file_exists($path)) {
-                // アクションクラス
-                include_once $path;
-                $action_name = str_replace(
-                    DIRECTORY_SEPARATOR, '_', $action_path);
-                if (class_exists($action_name)) {
-                    // インスタンス生成、処理を起動
-                    $action =& new $action_name;
-                    $action->process($moony, array_reverse($args));
-                    return;
-                }
+            if ($this->_invokeAction(
+                $action_path, $action_name, $moony, $args)) {
+                // アクションクラス生成、処理を起動
+                return;
             }
             $args[] = strtolower(array_pop($paths));
         }
 
         // 結局見つからなかった
-        return false;
+        if (!is_null($moony->default_action_name)) {
+            // デフォルトアクションが設定されている場合
+            $action_path = str_replace(
+                '_', DIRECTORY_SEPARATOR, $moony->default_action_name);
+            if ($this->_invokeAction(
+                $action_path, $moony->default_action_name, $moony, $args)) {
+                return;
+            }
+        }
+        if (!is_null($moony->default_redirect_url)) {
+            // デフォルトリダイレクト先が設定されている場合
+            if (!headers_sent()) {
+                if (ob_get_length() !== false) {
+                    ob_end_clean();
+                }
+                header('Location: ' . $moony->default_redirect_url);
+                return;
+            }
+        }
+
+        // 404エラー
+        header('HTTP/1.0 404 Not Found');
+        exit;
     }
 
     /**
@@ -98,5 +123,29 @@ class Moony_Router
         }
         return $path_info;
     }
+
+    /**
+     * アクションの処理を起動します。
+     *
+     * @access protected
+     * @param string $action_path アクションパス
+     * @param string $action_name アクションクラス名
+     * @param object $moony Moony
+     * @param array $args PATH_INFOとして渡されたパラメータの配列
+     */
+    function _invokeAction($action_path, $action_name, $moony, $args)
+    {
+        $path = $moony->action_dir .
+            DIRECTORY_SEPARATOR . $action_path . '.php';
+        if (file_exists($path)) {
+            include_once $path;
+            if (class_exists($action_name)) {
+                $action =& new $action_name;
+                $action->process($moony, array_reverse($args));
+                return true;
+            }
+        }
+        return false;
+    }
 }
 ?>
