@@ -41,5 +41,17 @@ class MoonyTest extends UnitTestCase
         $this->moony->setInternalEncoding('UTF-8');
         $this->assertEqual('UTF-8', $this->moony->internal_encoding);
     }
+
+    function testSetDefaultAction()
+    {
+        $this->moony->setDefaultAction('Foo_Bar');
+        $this->assertEqual('Foo_Bar', $this->moony->default_action_name);
+    }
+
+    function testSetDefaultRedirect()
+    {
+        $this->moony->setDefaultRedirect('http://example.com/');
+        $this->assertEqual('http://example.com/', $this->moony->default_redirect_url);
+    }
 }
 ?>
